@@ -16,8 +16,8 @@ import warnings
 import time
 import collections
 
-from setuptools.extern import six
-from setuptools.extern.six.moves import map
+import six
+from six.moves import map
 
 from setuptools import Command
 from setuptools.command.sdist import sdist
@@ -30,7 +30,7 @@ from pkg_resources import (
 import setuptools.unicode_utils as unicode_utils
 from setuptools.glob import glob
 
-from pkg_resources.extern import packaging
+import packaging
 
 
 def translate_pattern(glob):
@@ -112,7 +112,8 @@ def translate_pattern(glob):
         if not last_chunk:
             pat += sep
 
-    return re.compile(pat + r'\Z(?ms)')
+    pat += r'\Z'
+    return re.compile(pat, flags=re.MULTILINE|re.DOTALL)
 
 
 class egg_info(Command):
@@ -121,18 +122,13 @@ class egg_info(Command):
     user_options = [
         ('egg-base=', 'e', "directory containing .egg-info directories"
                            " (default: top of the source tree)"),
-        ('tag-svn-revision', 'r',
-         "Add subversion revision ID to version number"),
         ('tag-date', 'd', "Add date stamp (e.g. 20050528) to version number"),
         ('tag-build=', 'b', "Specify explicit tag to add to version number"),
-        ('no-svn-revision', 'R',
-         "Don't add subversion revision ID [default]"),
         ('no-date', 'D', "Don't include date stamp [default]"),
     ]
 
-    boolean_options = ['tag-date', 'tag-svn-revision']
+    boolean_options = ['tag-date']
     negative_opt = {
-        'no-svn-revision': 'tag-svn-revision',
         'no-date': 'tag-date',
     }
 
@@ -146,10 +142,22 @@ class egg_info(Command):
         self.broken_egg_info = False
         self.vtags = None
 
+    ####################################
+    # allow the 'tag_svn_revision' to be detected and
+    # set, supporting sdists built on older Setuptools.
+    @property
+    def tag_svn_revision(self):
+        pass
+
+    @tag_svn_revision.setter
+    def tag_svn_revision(self, value):
+        pass
+    ####################################
+
     def save_version_info(self, filename):
         """
-        Materialize the values of svn_revision and date into the
-        build tag. Install these keys in a deterministic order
+        Materialize the value of date into the
+        build tag. Install build keys in a deterministic order
         to avoid arbitrary reordering on subsequent builds.
         """
         # python 2.6 compatibility
@@ -422,7 +430,11 @@ class FileList(_FileList):
 
     def graft(self, dir):
         """Include all files from 'dir/'."""
-        found = distutils.filelist.findall(dir)
+        found = [
+            item
+            for match_dir in glob(dir)
+            for item in distutils.filelist.findall(match_dir)
+        ]
         self.extend(found)
         return bool(found)
 
